==> jc-1.4.0.tar.gz: soot/jimple/parser/node/TMult.h <==
// public final class soot.jimple.parser.node.TMult

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c44bf878040e3368 soot_jimple_parser_node_TMult
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TMult_H_
#define _JC_soot_jimple_parser_node_TMult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TMult$sub_refs	_jc_soot_jimple_parser_node_TMult$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TMult$sub_nonrefs	_jc_soot_jimple_parser_node_TMult$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TMult$refs	_jc_soot_jimple_parser_node_TMult$refs;
typedef struct _jc_soot_jimple_parser_node_TMult$nonrefs	_jc_soot_jimple_parser_node_TMult$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TMult$object	_jc_soot_jimple_parser_node_TMult$object;

typedef const struct _jc_soot_jimple_parser_node_TMult$vmethods	_jc_soot_jimple_parser_node_TMult$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TMult$vtable	_jc_soot_jimple_parser_node_TMult$vtable;
typedef const struct _jc_soot_jimple_parser_node_TMult$vtype	_jc_soot_jimple_parser_node_TMult$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TMult$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *);
extern void _jc_soot_jimple_parser_node_TMult$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, jint, jint);

// Virtual methods
extern void _jc_soot_jimple_parser_node_TMult$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TMult$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *);
extern void _jc_soot_jimple_parser_node_TMult$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TMult$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TMult$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_TMult$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TMult$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *);
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_TMult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TMult$vmethods	soot_jimple_parser_node_TMult;
};

// Vtype
struct _jc_soot_jimple_parser_node_TMult$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TMult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TMult$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TMult$refs {
    _jc_soot_jimple_parser_node_TMult$sub_refs	soot_jimple_parser_node_TMult;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TMult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TMult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TMult$sub_nonrefs	soot_jimple_parser_node_TMult;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TMult$object {
	_jc_soot_jimple_parser_node_TMult$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TMult$vtype	*vtype;
	_jc_soot_jimple_parser_node_TMult$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TMult$vtype _jc_soot_jimple_parser_node_TMult$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TMult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TMult$class_object;

#endif	/* _JC_soot_jimple_parser_node_TMult_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/TMult.h <==
// public final class soot.jimple.parser.node.TMult

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c44bf878040e3368 soot_jimple_parser_node_TMult
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TMult_H_
#define _JC_soot_jimple_parser_node_TMult_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TMult$sub_refs	_jc_soot_jimple_parser_node_TMult$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TMult$sub_nonrefs	_jc_soot_jimple_parser_node_TMult$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TMult$refs	_jc_soot_jimple_parser_node_TMult$refs;
typedef struct _jc_soot_jimple_parser_node_TMult$nonrefs	_jc_soot_jimple_parser_node_TMult$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TMult$object	_jc_soot_jimple_parser_node_TMult$object;

typedef const struct _jc_soot_jimple_parser_node_TMult$vmethods	_jc_soot_jimple_parser_node_TMult$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TMult$vtable	_jc_soot_jimple_parser_node_TMult$vtable;
typedef const struct _jc_soot_jimple_parser_node_TMult$vtype	_jc_soot_jimple_parser_node_TMult$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TMult$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TMult$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_TMult$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TMult$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TMult$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TMult$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TMult$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_TMult$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TMult$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *) _JC_JCNI_ATTR;
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_soot_jimple_parser_node_TMult$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_TMult$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TMult$vmethods	soot_jimple_parser_node_TMult;
};

// Vtype
struct _jc_soot_jimple_parser_node_TMult$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TMult$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TMult$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TMult$refs {
    _jc_soot_jimple_parser_node_TMult$sub_refs	soot_jimple_parser_node_TMult;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TMult$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TMult$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TMult$sub_nonrefs	soot_jimple_parser_node_TMult;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TMult$object {
	_jc_soot_jimple_parser_node_TMult$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TMult$vtype	*vtype;
	_jc_soot_jimple_parser_node_TMult$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TMult$vtype _jc_soot_jimple_parser_node_TMult$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TMult, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TMult$class_object;

#endif	/* _JC_soot_jimple_parser_node_TMult_H_ */
